PaneRenderFn

Type Alias PaneRenderFn 

pub type PaneRenderFn = fn(&mut Frame<'_>, Rect, &App, &DocumentSnapshot, &PaneState, bool, usize);
Renderer for one pane. Receives the same arguments as the dispatcher in crate::render::draw_pane_content: the frame, content rect, app state, the active document snapshot (used by the document fallback path), the pane state, an is_active flag, and the pane index (for inactive-pane stash lookups).