pub struct StyledSpan {
pub start: usize,
pub end: usize,
pub style: Style,
}Expand description
Byte-range span within one source line, carrying a semantic Style.
Fields
start: usizeByte offset within the line where the span starts.
end: usizeByte offset within the line (exclusive).
style: StyleTrait Implementations
Sourceimpl Clone for StyledSpan
impl Clone for StyledSpan
Sourcefn clone(&self) -> StyledSpan
fn clone(&self) -> StyledSpan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StyledSpan
Sourceimpl Debug for StyledSpan
impl Debug for StyledSpan
impl Eq for StyledSpan
Sourceimpl PartialEq for StyledSpan
impl PartialEq for StyledSpan
impl StructuralPartialEq for StyledSpan